Method: MerbMerchant::Billing::BeanstreamCore#initialize
- Defined in:
- lib/merb_merchant/billing/gateways/beanstream/beanstream_core.rb
#initialize(options = {}) ⇒ Object
Only :login is required by default, which is the merchant’s merchant ID. If you’d like to perform void, capture or credit transactions then you’ll also need to add a username and password to your account under administration -> account settings -> order settings -> Use username/password validation
54 55 56 57 58 |
# File 'lib/merb_merchant/billing/gateways/beanstream/beanstream_core.rb', line 54 def initialize( = {}) requires!(, :login) = super end |